@@ -86,7 +86,7 @@ class NoopManager(object):
         self.amphoraconfig[amphora.id, port.id] = (amphora.id, port.id,
                                                    'post_network_plug')
 
-    def post_vip_plug(self, load_balancer, amphorae_network_config):
+    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config):
         LOG.debug("Amphora %s no-op, post vip plug load balancer %s",
                   self.__class__.__name__, load_balancer.id)
         self.amphoraconfig[(load_balancer.id, id(amphorae_network_config))] = (
@@ -99,7 +99,9 @@ class NoopManager(object):
                                                     'update_amp_cert_file')
 
 
-class NoopAmphoraLoadBalancerDriver(driver_base.AmphoraLoadBalancerDriver):
+class NoopAmphoraLoadBalancerDriver(
+    driver_base.AmphoraLoadBalancerDriver,
+        driver_base.VRRPDriverMixin):
     def __init__(self):
         super(NoopAmphoraLoadBalancerDriver, self).__init__()
         self.driver = NoopManager()
@@ -136,10 +138,26 @@ class NoopAmphoraLoadBalancerDriver(driver_base.AmphoraLoadBalancerDriver):
 
         self.driver.post_network_plug(amphora, port)
 
-    def post_vip_plug(self, load_balancer, amphorae_network_config):
+    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config):
 
-        self.driver.post_vip_plug(load_balancer, amphorae_network_config)
+        self.driver.post_vip_plug(amphora,
+                                  load_balancer, amphorae_network_config)
 
     def upload_cert_amp(self, amphora, pem_file):
 
         self.driver.upload_cert_amp(amphora, pem_file)
+
+    def update_vrrp_conf(self, loadbalancer):
+        pass
+
+    def stop_vrrp_service(self, loadbalancer):
+        pass
+
+    def start_vrrp_service(self, loadbalancer):
+        pass
+
+    def reload_vrrp_service(self, loadbalancer):
+        pass
+
+    def get_vrrp_interface(self, amphora):
+        pass
