@@ -24,13 +24,10 @@ from oslo_reports import guru_meditation_report as gmr
 
 from octavia.common import service
 from octavia.controller.housekeeping import house_keeping
-from octavia.i18n import _LI
 from octavia import version
 
-
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
-CONF.import_group('house_keeping', 'octavia.common.config')
 
 spare_amp_thread_event = threading.Event()
 db_cleanup_thread_event = threading.Event()
@@ -42,43 +39,55 @@ def spare_amphora_check():
 
     # Read the interval from CONF
     interval = CONF.house_keeping.spare_check_interval
-    LOG.info(_LI("Spare check interval is set to %d sec"), interval)
+    LOG.info("Spare check interval is set to %d sec", interval)
 
     spare_amp = house_keeping.SpareAmphora()
-    while spare_amp_thread_event.is_set():
+    while not spare_amp_thread_event.is_set():
         LOG.debug("Initiating spare amphora check...")
-        spare_amp.spare_check()
-        time.sleep(interval)
+        try:
+            spare_amp.spare_check()
+        except Exception as e:
+            LOG.debug('spare_amphora caught the following exception and '
+                      'is restarting: {}'.format(e))
+        spare_amp_thread_event.wait(interval)
 
 
 def db_cleanup():
     """Perform db cleanup for old resources."""
     # Read the interval from CONF
     interval = CONF.house_keeping.cleanup_interval
-    LOG.info(_LI("DB cleanup interval is set to %d sec"), interval)
-    LOG.info(_LI('Amphora expiry age is %s seconds'),
+    LOG.info("DB cleanup interval is set to %d sec", interval)
+    LOG.info('Amphora expiry age is %s seconds',
              CONF.house_keeping.amphora_expiry_age)
-    LOG.info(_LI('Load balancer expiry age is %s seconds'),
+    LOG.info('Load balancer expiry age is %s seconds',
              CONF.house_keeping.load_balancer_expiry_age)
 
     db_cleanup = house_keeping.DatabaseCleanup()
-    while db_cleanup_thread_event.is_set():
+    while not db_cleanup_thread_event.is_set():
         LOG.debug("Initiating the cleanup of old resources...")
-        db_cleanup.delete_old_amphorae()
-        db_cleanup.cleanup_load_balancers()
-        time.sleep(interval)
+        try:
+            db_cleanup.delete_old_amphorae()
+            db_cleanup.cleanup_load_balancers()
+        except Exception as e:
+            LOG.debug('db_cleanup caught the following exception and '
+                      'is restarting: {}'.format(e))
+        db_cleanup_thread_event.wait(interval)
 
 
 def cert_rotation():
     """Perform certificate rotation."""
     interval = CONF.house_keeping.cert_interval
     LOG.info(
-        _LI("Expiring certificate check interval is set to %d sec") % interval)
+        "Expiring certificate check interval is set to %d sec", interval)
     cert_rotate = house_keeping.CertRotation()
-    while cert_rotate_thread_event.is_set():
+    while not cert_rotate_thread_event.is_set():
         LOG.debug("Initiating certification rotation ...")
-        cert_rotate.rotate()
-        time.sleep(interval)
+        try:
+            cert_rotate.rotate()
+        except Exception as e:
+            LOG.debug('cert_rotation caught the following exception and '
+                      'is restarting: {}'.format(e))
+        cert_rotate_thread_event.wait(interval)
 
 
 def main():
@@ -87,24 +96,21 @@ def main():
     gmr.TextGuruMeditation.setup_autorun(version)
 
     timestamp = str(datetime.datetime.utcnow())
-    LOG.info(_LI("Starting house keeping at %s"), timestamp)
+    LOG.info("Starting house keeping at %s", timestamp)
 
     # Thread to perform spare amphora check
     spare_amp_thread = threading.Thread(target=spare_amphora_check)
     spare_amp_thread.daemon = True
-    spare_amp_thread_event.set()
     spare_amp_thread.start()
 
     # Thread to perform db cleanup
     db_cleanup_thread = threading.Thread(target=db_cleanup)
     db_cleanup_thread.daemon = True
-    db_cleanup_thread_event.set()
     db_cleanup_thread.start()
 
     # Thread to perform certificate rotation
     cert_rotate_thread = threading.Thread(target=cert_rotation)
     cert_rotate_thread.daemon = True
-    cert_rotate_thread_event.set()
     cert_rotate_thread.start()
 
     # Try-Exception block should be at the end to gracefully exit threads
@@ -112,11 +118,11 @@ def main():
         while True:
             time.sleep(1)
     except KeyboardInterrupt:
-        LOG.info(_LI("Attempting to gracefully terminate House-Keeping"))
-        spare_amp_thread_event.clear()
-        db_cleanup_thread_event.clear()
-        cert_rotate_thread_event.clear()
+        LOG.info("Attempting to gracefully terminate House-Keeping")
+        spare_amp_thread_event.set()
+        db_cleanup_thread_event.set()
+        cert_rotate_thread_event.set()
         spare_amp_thread.join()
         db_cleanup_thread.join()
         cert_rotate_thread.join()
-        LOG.info(_LI("House-Keeping process terminated"))
+        LOG.info("House-Keeping process terminated")
