@@ -19,11 +19,10 @@
 """Utilities and helper functions."""
 
 import base64
-import datetime
 import hashlib
-import random
 import socket
 
+import netaddr
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -38,22 +37,6 @@ def get_hostname():
     return socket.gethostname()
 
 
-def get_random_string(length):
-    """Get a random hex string of the specified length.
-
-    based on Cinder library
-      cinder/transfer/api.py
-    """
-    rndstr = ""
-    random.seed(datetime.datetime.now().microsecond)
-    while len(rndstr) < length:
-        rndstr += hashlib.sha224(
-            str(random.random()).encode('ascii')
-        ).hexdigest()
-
-    return rndstr[0:length]
-
-
 def base64_sha1_string(string_to_hash):
     hash_str = hashlib.sha1(string_to_hash.encode('utf-8')).digest()
     b64_str = base64.b64encode(hash_str, str.encode('_-', 'ascii'))
@@ -70,6 +53,31 @@ def get_network_driver():
     return network_driver
 
 
+def is_ipv6(ip_address):
+    """Check if ip address is IPv6 address."""
+    ip = netaddr.IPAddress(ip_address)
+    return ip.version == 6
+
+
+def is_ipv6_lla(ip_address):
+    """Check if ip address is IPv6 link local address."""
+    ip = netaddr.IPAddress(ip_address)
+    return ip.version == 6 and ip.is_link_local()
+
+
+def ip_port_str(ip_address, port):
+    """Return IP port as string representation depending on address family."""
+    ip = netaddr.IPAddress(ip_address)
+    if ip.version == 4:
+        return "{ip}:{port}".format(ip=ip, port=port)
+    elif ip.version == 6:
+        return "[{ip}]:{port}".format(ip=ip, port=port)
+
+
+def netmask_to_prefix(netmask):
+    return netaddr.IPAddress(netmask).netmask_bits()
+
+
 class exception_logger(object):
     """Wrap a function and log raised exception
 
