@@ -26,7 +26,7 @@ from octavia.amphorae.backends.agent import agent_jinja_cfg
 from octavia.common import constants
 from octavia.common import exceptions
 from octavia.common.jinja import user_data_jinja_cfg
-from octavia.i18n import _LE, _LW
+from octavia.controller.worker import amphora_rate_limit
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -42,12 +42,15 @@ class BaseComputeTask(task.Task):
             name=CONF.controller_worker.compute_driver,
             invoke_on_load=True
         ).driver
+        self.rate_limit = amphora_rate_limit.AmphoraBuildRateLimit()
 
 
 class ComputeCreate(BaseComputeTask):
     """Create the compute instance for a new amphora."""
 
-    def execute(self, amphora_id, ports=None, config_drive_files=None,
+    def execute(self, amphora_id,
+                build_type_priority=constants.LB_CREATE_NORMAL_PRIORITY,
+                ports=None, config_drive_files=None,
                 server_group_id=None):
         """Create an amphora
 
@@ -55,9 +58,6 @@ class ComputeCreate(BaseComputeTask):
         """
         ports = ports or []
         network_ids = CONF.controller_worker.amp_boot_network_list[:]
-        # TODO(ptoohill) amp_network is now deprecated, remove when ready...
-        if CONF.controller_worker.amp_network:
-            network_ids.append(CONF.controller_worker.amp_network)
         config_drive_files = config_drive_files or {}
         user_data = None
         LOG.debug("Compute create execute for amphora with id %s", amphora_id)
@@ -68,6 +68,10 @@ class ComputeCreate(BaseComputeTask):
         key_name = None if not ssh_access else ssh_key
 
         try:
+            if CONF.haproxy_amphora.build_rate_limit != -1:
+                self.rate_limit.add_to_build_request_queue(
+                    amphora_id, build_type_priority)
+
             agent_cfg = agent_jinja_cfg.AgentJinjaTemplater()
             config_drive_files['/etc/octavia/amphora-agent.conf'] = (
                 agent_cfg.build_agent_config(amphora_id))
@@ -96,7 +100,7 @@ class ComputeCreate(BaseComputeTask):
             return compute_id
 
         except Exception:
-            LOG.exception(_LE("Compute create for amphora id: %s failed"),
+            LOG.exception("Compute create for amphora id: %s failed",
                           amphora_id)
             raise
 
@@ -108,18 +112,19 @@ class ComputeCreate(BaseComputeTask):
         if isinstance(result, failure.Failure):
             return
         compute_id = result
-        LOG.warning(_LW("Reverting compute create for amphora with id"
-                        "%(amp)s and compute id: %(comp)s"),
+        LOG.warning("Reverting compute create for amphora with id"
+                    "%(amp)s and compute id: %(comp)s",
                     {'amp': amphora_id, 'comp': compute_id})
         try:
             self.compute.delete(compute_id)
         except Exception:
-            LOG.exception(_LE("Reverting compute create failed"))
+            LOG.exception("Reverting compute create failed")
 
 
 class CertComputeCreate(ComputeCreate):
-    def execute(self, amphora_id, server_pem, ports=None,
-                server_group_id=None):
+    def execute(self, amphora_id, server_pem,
+                build_type_priority=constants.LB_CREATE_NORMAL_PRIORITY,
+                ports=None, server_group_id=None):
         """Create an amphora
 
         :returns: an amphora
@@ -132,7 +137,8 @@ class CertComputeCreate(ComputeCreate):
             '/etc/octavia/certs/server.pem': server_pem,
             '/etc/octavia/certs/client_ca.pem': ca}
         return super(CertComputeCreate, self).execute(
-            amphora_id, ports=ports, config_drive_files=config_drive_files,
+            amphora_id, build_type_priority=build_type_priority,
+            ports=ports, config_drive_files=config_drive_files,
             server_group_id=server_group_id)
 
 
@@ -150,7 +156,7 @@ class DeleteAmphoraeOnLoadBalancer(BaseComputeTask):
             try:
                 self.compute.delete(amp.compute_id)
             except Exception:
-                LOG.exception(_LE("Compute delete for amphora id: %s failed"),
+                LOG.exception("Compute delete for amphora id: %s failed",
                               amp.id)
                 raise
 
@@ -162,7 +168,7 @@ class ComputeDelete(BaseComputeTask):
         try:
             self.compute.delete(amphora.compute_id)
         except Exception:
-            LOG.exception(_LE("Compute delete for amphora id: %s failed"),
+            LOG.exception("Compute delete for amphora id: %s failed",
                           amphora.id)
             raise
 
@@ -170,18 +176,20 @@ class ComputeDelete(BaseComputeTask):
 class ComputeWait(BaseComputeTask):
     """Wait for the compute driver to mark the amphora active."""
 
-    def execute(self, compute_id):
+    def execute(self, compute_id, amphora_id):
         """Wait for the compute driver to mark the amphora active
 
         :raises: Generic exception if the amphora is not active
         :returns: An amphora object
         """
         for i in range(CONF.controller_worker.amp_active_retries):
-            amp = self.compute.get_amphora(compute_id)
+            amp, fault = self.compute.get_amphora(compute_id)
             if amp.status == constants.ACTIVE:
+                if CONF.haproxy_amphora.build_rate_limit != -1:
+                    self.rate_limit.remove_from_build_req_queue(amphora_id)
                 return amp
             elif amp.status == constants.ERROR:
-                raise exceptions.ComputeBuildException()
+                raise exceptions.ComputeBuildException(fault=fault)
             time.sleep(CONF.controller_worker.amp_active_wait_sec)
 
         raise exceptions.ComputeWaitTimeoutException()
@@ -199,7 +207,7 @@ class NovaServerGroupCreate(BaseComputeTask):
 
         name = 'octavia-lb-' + loadbalancer_id
         server_group = self.compute.create_server_group(
-            name, constants.ANTI_AFFINITY)
+            name, CONF.nova.anti_affinity_policy)
         LOG.debug("Server Group created with id: %s for load balancer id: "
                   "%s", server_group.id, loadbalancer_id)
         return server_group.id
@@ -210,14 +218,14 @@ class NovaServerGroupCreate(BaseComputeTask):
         :param result: here it refers to server group id
         """
         server_group_id = result
-        LOG.warning(_LW("Reverting server group create with id:%s"),
+        LOG.warning("Reverting server group create with id:%s",
                     server_group_id)
         try:
             self.compute.delete_server_group(server_group_id)
         except Exception as e:
-            LOG.error(_LE("Failed to delete server group.  Resources may "
-                          "still be in use for server group: %(sg)s due to "
-                          "error: %(except)s"),
+            LOG.error("Failed to delete server group.  Resources may "
+                      "still be in use for server group: %(sg)s due to "
+                      "error: %(except)s",
                       {'sg': server_group_id, 'except': e})
 
 
