@@ -22,7 +22,6 @@ from taskflow.types import failure
 
 from octavia.common import constants
 from octavia.common import utils
-from octavia.i18n import _LW, _LE
 from octavia.network import base
 from octavia.network import data_models as n_data_models
 
@@ -48,12 +47,9 @@ class CalculateAmphoraDelta(BaseNetworkTask):
 
         # Figure out what networks we want
         # seed with lb network(s)
-        subnet = self.network_driver.get_subnet(loadbalancer.vip.subnet_id)
-        # TODO(ptoohill): amp_network is deprecated, remove when ready...
-        desired_network_ids = {subnet.network_id}.union(
+        vrrp_port = self.network_driver.get_port(amphora.vrrp_port_id)
+        desired_network_ids = {vrrp_port.network_id}.union(
             CONF.controller_worker.amp_boot_network_list)
-        if CONF.controller_worker.amp_network:
-            desired_network_ids.add(CONF.controller_worker.amp_network)
 
         for pool in loadbalancer.pools:
             member_networks = [
@@ -94,8 +90,9 @@ class CalculateDelta(BaseNetworkTask):
         """Compute which NICs need to be plugged
 
         for the amphora to become operational.
+
         :param loadbalancer: the loadbalancer to calculate deltas for all
-                              amphorae
+                             amphorae
         :returns: dict of octavia.network.data_models.Delta keyed off amphora
                   id
         """
@@ -151,7 +148,7 @@ class PlugNetworks(BaseNetworkTask):
     def revert(self, amphora, delta, *args, **kwargs):
         """Handle a failed network plug by removing all nics added."""
 
-        LOG.warning(_LW("Unable to plug networks for amp id %s"), amphora.id)
+        LOG.warning("Unable to plug networks for amp id %s", amphora.id)
         if not delta:
             return
 
@@ -186,7 +183,7 @@ class UnPlugNetworks(BaseNetworkTask):
                 LOG.debug("Network %d not found", nic.network_id)
                 pass
             except Exception:
-                LOG.exception(_LE("Unable to unplug network"))
+                LOG.exception("Unable to unplug network")
                 pass  # Todo(german) follow up if that makes sense
 
 
@@ -241,7 +238,7 @@ class HandleNetworkDeltas(BaseNetworkTask):
                 except base.NetworkNotFound:
                     LOG.debug("Network %d not found ", nic.network_id)
                 except Exception:
-                    LOG.exception(_LE("Unable to unplug network"))
+                    LOG.exception("Unable to unplug network")
         return added_ports
 
     def revert(self, result, deltas, *args, **kwargs):
@@ -250,7 +247,7 @@ class HandleNetworkDeltas(BaseNetworkTask):
         if isinstance(result, failure.Failure):
             return
         for amp_id, delta in six.iteritems(deltas):
-            LOG.warning(_LW("Unable to plug networks for amp id %s"),
+            LOG.warning("Unable to plug networks for amp id %s",
                         delta.amphora_id)
             if not delta:
                 return
@@ -280,7 +277,7 @@ class PlugVIP(BaseNetworkTask):
 
         if isinstance(result, failure.Failure):
             return
-        LOG.warning(_LW("Unable to plug VIP for loadbalancer id %s"),
+        LOG.warning("Unable to plug VIP for loadbalancer id %s",
                     loadbalancer.id)
 
         try:
@@ -294,9 +291,8 @@ class PlugVIP(BaseNetworkTask):
 
             self.network_driver.unplug_vip(loadbalancer, loadbalancer.vip)
         except Exception as e:
-            LOG.error(_LE("Failed to unplug VIP.  Resources may still "
-                          "be in use from vip: %(vip)s due to "
-                          "error: %(except)s"),
+            LOG.error("Failed to unplug VIP.  Resources may still "
+                      "be in use from vip: %(vip)s due to error: %(except)s",
                       {'vip': loadbalancer.vip.ip_address, 'except': e})
 
 
@@ -310,7 +306,7 @@ class UnplugVIP(BaseNetworkTask):
         try:
             self.network_driver.unplug_vip(loadbalancer, loadbalancer.vip)
         except Exception:
-            LOG.exception(_LE("Unable to unplug vip from load balancer %s"),
+            LOG.exception("Unable to unplug vip from load balancer %s",
                           loadbalancer.id)
 
 
@@ -331,16 +327,15 @@ class AllocateVIP(BaseNetworkTask):
         """Handle a failure to allocate vip."""
 
         if isinstance(result, failure.Failure):
-            LOG.exception(_LE("Unable to allocate VIP"))
+            LOG.exception("Unable to allocate VIP")
             return
         vip = result
-        LOG.warning(_LW("Deallocating vip %s"), vip.ip_address)
+        LOG.warning("Deallocating vip %s", vip.ip_address)
         try:
             self.network_driver.deallocate_vip(vip)
         except Exception as e:
-            LOG.error(_LE("Failed to deallocate VIP.  Resources may still "
-                          "be in use from vip: %(vip)s due to "
-                          "error: %(except)s"),
+            LOG.error("Failed to deallocate VIP.  Resources may still "
+                      "be in use from vip: %(vip)s due to error: %(except)s",
                       {'vip': vip.ip_address, 'except': e})
 
 
@@ -418,9 +413,9 @@ class PlugPorts(BaseNetworkTask):
 
     def execute(self, amphora, ports):
         for port in ports:
-            LOG.debug('Plugging port ID: {port_id} into compute instance: '
-                      '{compute_id}.'.format(port_id=port.id,
-                                             compute_id=amphora.compute_id))
+            LOG.debug('Plugging port ID: %(port_id)s into compute instance: '
+                      '%(compute_id)s.',
+                      {'port_id': port.id, 'compute_id': amphora.compute_id})
             self.network_driver.plug_port(amphora, port)
 
 
@@ -429,9 +424,9 @@ class PlugVIPPort(BaseNetworkTask):
 
     def execute(self, amphora, amphorae_network_config):
         vrrp_port = amphorae_network_config.get(amphora.id).vrrp_port
-        LOG.debug('Plugging VIP VRRP port ID: {port_id} into compute '
-                  'instance: {compute_id}.'.format(
-                      port_id=vrrp_port.id, compute_id=amphora.compute_id))
+        LOG.debug('Plugging VIP VRRP port ID: %(port_id)s into compute '
+                  'instance: %(compute_id)s.',
+                  {'port_id': vrrp_port.id, 'compute_id': amphora.compute_id})
         self.network_driver.plug_port(amphora, vrrp_port)
 
     def revert(self, result, amphora, amphorae_network_config,
@@ -441,15 +436,14 @@ class PlugVIPPort(BaseNetworkTask):
             vrrp_port = amphorae_network_config.get(amphora.id).vrrp_port
             self.network_driver.unplug_port(amphora, vrrp_port)
         except Exception:
-            LOG.warning(_LW('Failed to unplug vrrp port: {port} '
-                            'from amphora: {amp}').format(port=vrrp_port.id,
-                                                          amp=amphora.id))
+            LOG.warning('Failed to unplug vrrp port: %(port)s from amphora: '
+                        '%(amp)s', {'port': vrrp_port.id, 'amp': amphora.id})
 
 
 class WaitForPortDetach(BaseNetworkTask):
     """Task to wait for the neutron ports to detach from an amphora."""
 
     def execute(self, amphora):
-        LOG.debug('Waiting for ports to detach from amphora: '
-                  '{amp_id}.'.format(amp_id=amphora.id))
+        LOG.debug('Waiting for ports to detach from amphora: %(amp_id)s.',
+                  {'amp_id': amphora.id})
         self.network_driver.wait_for_port_detach(amphora)
