@@ -20,6 +20,14 @@ from sqlalchemy import orm
 from sqlalchemy.orm import validates
 from sqlalchemy.sql import func
 
+from octavia.api.v2.types import health_monitor
+from octavia.api.v2.types import l7policy
+from octavia.api.v2.types import l7rule
+from octavia.api.v2.types import listener
+from octavia.api.v2.types import load_balancer
+from octavia.api.v2.types import member
+from octavia.api.v2.types import pool
+from octavia.api.v2.types import quotas
 from octavia.common import data_models
 from octavia.db import base_models
 
@@ -84,6 +92,24 @@ class L7PolicyAction(base_models.BASE, base_models.LookupTableMixin):
     __tablename__ = "l7policy_action"
 
 
+class AmphoraBuildSlots(base_models.BASE):
+
+    __tablename__ = "amphora_build_slots"
+
+    id = sa.Column(sa.Integer(), primary_key=True)
+    slots_used = sa.Column(sa.Integer())
+
+
+class AmphoraBuildRequest(base_models.BASE):
+
+    __tablename__ = "amphora_build_request"
+
+    amphora_id = sa.Column(sa.String(36), nullable=True, primary_key=True)
+    priority = sa.Column(sa.Integer())
+    created_time = sa.Column(sa.DateTime, default=func.now(), nullable=False)
+    status = sa.Column(sa.String(16), default='WAITING', nullable=False)
+
+
 class SessionPersistence(base_models.BASE):
 
     __data_model__ = data_models.SessionPersistence
@@ -126,28 +152,29 @@ class ListenerStatistics(base_models.BASE):
     bytes_out = sa.Column(sa.BigInteger, nullable=False)
     active_connections = sa.Column(sa.Integer, nullable=False)
     total_connections = sa.Column(sa.BigInteger, nullable=False)
+    request_errors = sa.Column(sa.BigInteger, nullable=False)
 
-    @staticmethod
     @validates('bytes_in', 'bytes_out',
-               'active_connections', 'total_connections')
-    def validate_non_negative_int(key, value):
+               'active_connections', 'total_connections',
+               'request_errors')
+    def validate_non_negative_int(self, key, value):
         if value < 0:
             data = {'key': key, 'value': value}
-            raise ValueError(data)
-            # TODO(trevor-vardeman): Repair this functionality after OpenStack
-            # Common is in
-            # raise ValueError(_('The %(key)s field can not have '
-            #                   'negative value. '
-            #                   'Current value is %(value)d.') % data)
+            raise ValueError(_('The %(key)s field can not have '
+                               'negative value. '
+                               'Current value is %(value)d.') % data)
         return value
 
 
 class Member(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
-             models.TimestampMixin):
+             models.TimestampMixin, base_models.NameMixin):
 
     __data_model__ = data_models.Member
 
     __tablename__ = "member"
+
+    __v2_wsme__ = member.MemberResponse
+
     __table_args__ = (
         sa.UniqueConstraint('pool_id', 'ip_address', 'protocol_port',
                             name='uq_member_pool_id_address_protocol_port'),
@@ -161,6 +188,13 @@ class Member(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
     ip_address = sa.Column('ip_address', sa.String(64), nullable=False)
     protocol_port = sa.Column(sa.Integer, nullable=False)
     weight = sa.Column(sa.Integer, nullable=True)
+    monitor_address = sa.Column(sa.String(64), nullable=True)
+    monitor_port = sa.Column(sa.Integer, nullable=True)
+    provisioning_status = sa.Column(
+        sa.String(16),
+        sa.ForeignKey("provisioning_status.name",
+                      name="fk_member_provisioning_status_name"),
+        nullable=False)
     operating_status = sa.Column(
         sa.String(16),
         sa.ForeignKey("operating_status.name",
@@ -170,19 +204,18 @@ class Member(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
     pool = orm.relationship("Pool", backref=orm.backref("members",
                                                         uselist=True,
                                                         cascade="delete"))
-    provisioning_status = sa.Column(
-        sa.String(16),
-        sa.ForeignKey("provisioning_status.name",
-                      name="fk_member_provisioning_status_name"),
-        nullable=True)
 
 
-class HealthMonitor(base_models.BASE, base_models.ProjectMixin):
+class HealthMonitor(base_models.BASE, base_models.IdMixin,
+                    base_models.ProjectMixin, models.TimestampMixin,
+                    base_models.NameMixin):
 
     __data_model__ = data_models.HealthMonitor
 
     __tablename__ = "health_monitor"
 
+    __v2_wsme__ = health_monitor.HealthMonitorResponse
+
     type = sa.Column(
         sa.String(36),
         sa.ForeignKey("health_monitor_type.name",
@@ -191,7 +224,7 @@ class HealthMonitor(base_models.BASE, base_models.ProjectMixin):
     pool_id = sa.Column(
         sa.String(36),
         sa.ForeignKey("pool.id", name="fk_health_monitor_pool_id"),
-        nullable=False, primary_key=True)
+        nullable=False)
     delay = sa.Column(sa.Integer, nullable=False)
     timeout = sa.Column(sa.Integer, nullable=False)
     fall_threshold = sa.Column(sa.Integer, nullable=False)
@@ -208,17 +241,23 @@ class HealthMonitor(base_models.BASE, base_models.ProjectMixin):
         sa.String(16),
         sa.ForeignKey("provisioning_status.name",
                       name="fk_health_monitor_provisioning_status_name"),
-        nullable=True)
+        nullable=False)
+    operating_status = sa.Column(
+        sa.String(16),
+        sa.ForeignKey("operating_status.name",
+                      name="fk_health_monitor_operating_status_name"),
+        nullable=False)
 
 
 class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
-           models.TimestampMixin):
+           models.TimestampMixin, base_models.NameMixin):
 
     __data_model__ = data_models.Pool
 
     __tablename__ = "pool"
 
-    name = sa.Column(sa.String(255), nullable=True)
+    __v2_wsme__ = pool.PoolResponse
+
     description = sa.Column(sa.String(255), nullable=True)
     protocol = sa.Column(
         sa.String(16),
@@ -228,6 +267,11 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
         sa.String(255),
         sa.ForeignKey("algorithm.name", name="fk_pool_algorithm_name"),
         nullable=False)
+    provisioning_status = sa.Column(
+        sa.String(16),
+        sa.ForeignKey("provisioning_status.name",
+                      name="fk_pool_provisioning_status_name"),
+        nullable=False)
     operating_status = sa.Column(
         sa.String(16),
         sa.ForeignKey("operating_status.name",
@@ -242,11 +286,6 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
                                      backref=orm.backref("pools",
                                                          uselist=True,
                                                          cascade="delete"))
-    provisioning_status = sa.Column(
-        sa.String(16),
-        sa.ForeignKey("provisioning_status.name",
-                      name="fk_pool_provisioning_status_name"),
-        nullable=True)
 
     # This property should be a unique list of any listeners that reference
     # this pool as its default_pool and any listeners referenced by enabled
@@ -267,13 +306,15 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
 
 
 class LoadBalancer(base_models.BASE, base_models.IdMixin,
-                   base_models.ProjectMixin, models.TimestampMixin):
+                   base_models.ProjectMixin, models.TimestampMixin,
+                   base_models.NameMixin):
 
     __data_model__ = data_models.LoadBalancer
 
     __tablename__ = "load_balancer"
 
-    name = sa.Column(sa.String(255), nullable=True)
+    __v2_wsme__ = load_balancer.LoadBalancerResponse
+
     description = sa.Column(sa.String(255), nullable=True)
     provisioning_status = sa.Column(
         sa.String(16),
@@ -334,23 +375,27 @@ class Vip(base_models.BASE):
     ip_address = sa.Column(sa.String(64), nullable=True)
     port_id = sa.Column(sa.String(36), nullable=True)
     subnet_id = sa.Column(sa.String(36), nullable=True)
+    network_id = sa.Column(sa.String(36), nullable=True)
     load_balancer = orm.relationship("LoadBalancer", uselist=False,
                                      backref=orm.backref("vip", uselist=False,
                                                          cascade="delete"))
 
 
 class Listener(base_models.BASE, base_models.IdMixin,
-               base_models.ProjectMixin, models.TimestampMixin):
+               base_models.ProjectMixin, models.TimestampMixin,
+               base_models.NameMixin):
 
     __data_model__ = data_models.Listener
 
     __tablename__ = "listener"
+
+    __v2_wsme__ = listener.ListenerResponse
+
     __table_args__ = (
         sa.UniqueConstraint('load_balancer_id', 'protocol_port',
                             name='uq_listener_load_balancer_id_protocol_port'),
     )
 
-    name = sa.Column(sa.String(255), nullable=True)
     description = sa.Column(sa.String(255), nullable=True)
     protocol = sa.Column(
         sa.String(16),
@@ -476,12 +521,15 @@ class AmphoraHealth(base_models.BASE):
     busy = sa.Column(sa.Boolean(), default=False, nullable=False)
 
 
-class L7Rule(base_models.BASE, base_models.IdMixin):
+class L7Rule(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
+             models.TimestampMixin):
 
     __data_model__ = data_models.L7Rule
 
     __tablename__ = "l7rule"
 
+    __v2_wsme__ = l7rule.L7RuleResponse
+
     l7policy_id = sa.Column(
         sa.String(36),
         sa.ForeignKey("l7policy.id", name="fk_l7rule_l7policy_id"),
@@ -501,6 +549,7 @@ class L7Rule(base_models.BASE, base_models.IdMixin):
     key = sa.Column(sa.String(255), nullable=True)
     value = sa.Column(sa.String(255), nullable=False)
     invert = sa.Column(sa.Boolean(), default=False, nullable=False)
+    enabled = sa.Column(sa.Boolean(), nullable=False)
     l7policy = orm.relationship("L7Policy", uselist=False,
                                 backref=orm.backref("l7rules",
                                                     uselist=True,
@@ -509,16 +558,23 @@ class L7Rule(base_models.BASE, base_models.IdMixin):
         sa.String(16),
         sa.ForeignKey("provisioning_status.name",
                       name="fk_l7rule_provisioning_status_name"),
-        nullable=True)
+        nullable=False)
+    operating_status = sa.Column(
+        sa.String(16),
+        sa.ForeignKey("operating_status.name",
+                      name="fk_l7rule_operating_status_name"),
+        nullable=False)
 
 
-class L7Policy(base_models.BASE, base_models.IdMixin):
+class L7Policy(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
+               models.TimestampMixin, base_models.NameMixin):
 
     __data_model__ = data_models.L7Policy
 
     __tablename__ = "l7policy"
 
-    name = sa.Column(sa.String(255), nullable=True)
+    __v2_wsme__ = l7policy.L7PolicyResponse
+
     description = sa.Column(sa.String(255), nullable=True)
     listener_id = sa.Column(
         sa.String(36),
@@ -555,4 +611,30 @@ class L7Policy(base_models.BASE, base_models.IdMixin):
         sa.String(16),
         sa.ForeignKey("provisioning_status.name",
                       name="fk_l7policy_provisioning_status_name"),
-        nullable=True)
+        nullable=False)
+    operating_status = sa.Column(
+        sa.String(16),
+        sa.ForeignKey("operating_status.name",
+                      name="fk_l7policy_operating_status_name"),
+        nullable=False)
+
+
+class Quotas(base_models.BASE):
+
+    __data_model__ = data_models.Quotas
+
+    __tablename__ = "quotas"
+
+    __v2_wsme__ = quotas.QuotaAllBase
+
+    project_id = sa.Column(sa.String(36), primary_key=True)
+    health_monitor = sa.Column(sa.Integer(), nullable=True)
+    listener = sa.Column(sa.Integer(), nullable=True)
+    load_balancer = sa.Column(sa.Integer(), nullable=True)
+    member = sa.Column(sa.Integer(), nullable=True)
+    pool = sa.Column(sa.Integer(), nullable=True)
+    in_use_health_monitor = sa.Column(sa.Integer(), nullable=True)
+    in_use_listener = sa.Column(sa.Integer(), nullable=True)
+    in_use_load_balancer = sa.Column(sa.Integer(), nullable=True)
+    in_use_member = sa.Column(sa.Integer(), nullable=True)
+    in_use_pool = sa.Column(sa.Integer(), nullable=True)
