@@ -17,6 +17,7 @@ import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
+import requests
 import requests_mock
 import six
 
@@ -26,15 +27,19 @@ from octavia.amphorae.drivers.haproxy import rest_api_driver as driver
 from octavia.db import models
 from octavia.network import data_models as network_models
 from octavia.tests.unit import base as base
+from octavia.tests.unit.common.sample_configs import sample_certs
 from octavia.tests.unit.common.sample_configs import sample_configs
 
 FAKE_CIDR = '198.51.100.0/24'
 FAKE_GATEWAY = '192.51.100.1'
-FAKE_IP = 'fake'
+FAKE_IP = '192.0.2.10'
+FAKE_IPV6 = '2001:db8::cafe'
+FAKE_IPV6_LLA = 'fe80::00ff:fe00:cafe'
 FAKE_PEM_FILENAME = "file_name"
 FAKE_UUID_1 = uuidutils.generate_uuid()
 FAKE_VRRP_IP = '10.1.0.1'
 FAKE_MAC_ADDRESS = '123'
+FAKE_MTU = 1450
 
 
 class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
@@ -61,8 +66,10 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.fixed_ip = mock.MagicMock()
         self.fixed_ip.ip_address = '198.51.100.5'
         self.fixed_ip.subnet.cidr = '198.51.100.0/24'
+        self.network = network_models.Network(mtu=FAKE_MTU)
         self.port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
-                                        fixed_ips=[self.fixed_ip])
+                                        fixed_ips=[self.fixed_ip],
+                                        network=self.network)
 
         self.host_routes = [network_models.HostRoute(destination=DEST1,
                                                      nexthop=NEXTHOP),
@@ -74,12 +81,13 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                             'gateway': FAKE_GATEWAY,
                             'mac_address': FAKE_MAC_ADDRESS,
                             'vrrp_ip': self.amp.vrrp_ip,
+                            'mtu': FAKE_MTU,
                             'host_routes': host_routes_data}
 
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
     @mock.patch('octavia.common.tls_utils.cert_parser.get_host_names')
     def test_update(self, mock_cert, mock_load_crt):
-        mock_cert.return_value = {'cn': 'aFakeCN'}
+        mock_cert.return_value = {'cn': sample_certs.X509_CERT_CN}
         sconts = []
         for sni_container in self.sl.sni_containers:
             sconts.append(sni_container.tls_container)
@@ -88,7 +96,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             'sni_certs': sconts
         }
         self.driver.client.get_cert_md5sum.side_effect = [
-            exc.NotFound, 'Fake_MD5', 'd41d8cd98f00b204e9800998ecf8427e']
+            exc.NotFound, 'Fake_MD5', 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa']
         self.driver.jinja.build_config.side_effect = ['fake_config']
         self.driver.client.get_listener_status.side_effect = [
             dict(status='ACTIVE')]
@@ -99,18 +107,24 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         # verify result
         # this is called 3 times
         self.driver.client.get_cert_md5sum.assert_called_with(
-            self.amp, self.sl.id, 'aFakeCN.pem')
+            self.amp, self.sl.id, sample_certs.X509_CERT_CN_3 + '.pem')
         # this is called three times (last MD5 matches)
-        fp1 = ('--imapem1--\n\n--imakey1--\n'
-               '\n--imainter1--\n\n--imainter1too--\n')
-        fp2 = ('--imapem2--\n\n--imakey2--\n'
-               '\n--imainter2--\n\n--imainter2too--\n')
-        fp3 = ('--imapem3--\n\n--imakey3--\n'
-               '\n--imainter3--\n\n--imainter3too--\n')
+        fp1 = b'\n'.join([sample_certs.X509_CERT,
+                          sample_certs.X509_CERT_KEY,
+                          sample_certs.X509_IMDS]) + b'\n'
+        fp2 = b'\n'.join([sample_certs.X509_CERT_2,
+                          sample_certs.X509_CERT_KEY_2,
+                          sample_certs.X509_IMDS]) + b'\n'
+        fp3 = b'\n'.join([sample_certs.X509_CERT_3,
+                          sample_certs.X509_CERT_KEY_3,
+                          sample_certs.X509_IMDS]) + b'\n'
         ucp_calls = [
-            mock.call(self.amp, self.sl.id, 'aFakeCN.pem', fp1),
-            mock.call(self.amp, self.sl.id, 'aFakeCN.pem', fp2),
-            mock.call(self.amp, self.sl.id, 'aFakeCN.pem', fp3)
+            mock.call(self.amp, self.sl.id,
+                      sample_certs.X509_CERT_CN + '.pem', fp1),
+            mock.call(self.amp, self.sl.id,
+                      sample_certs.X509_CERT_CN_2 + '.pem', fp2),
+            mock.call(self.amp, self.sl.id,
+                      sample_certs.X509_CERT_CN_3 + '.pem', fp3)
         ]
         self.driver.client.upload_cert_pem.assert_has_calls(ucp_calls,
                                                             any_order=True)
@@ -166,10 +180,14 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
 
     def test_post_network_plug(self):
         # Test dhcp path
-        port = network_models.Port(mac_address=FAKE_MAC_ADDRESS, fixed_ips=[])
+        port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
+                                   fixed_ips=[],
+                                   network=self.network)
         self.driver.post_network_plug(self.amp, port)
         self.driver.client.plug_network.assert_called_once_with(
-            self.amp, dict(mac_address=FAKE_MAC_ADDRESS, fixed_ips=[]))
+            self.amp, dict(mac_address=FAKE_MAC_ADDRESS,
+                           fixed_ips=[],
+                           mtu=FAKE_MTU))
 
         self.driver.client.plug_network.reset_mock()
 
@@ -179,7 +197,8 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             self.amp, dict(mac_address=FAKE_MAC_ADDRESS,
                            fixed_ips=[dict(ip_address='198.51.100.5',
                                            subnet_cidr='198.51.100.0/24',
-                                           host_routes=[])]))
+                                           host_routes=[])],
+                           mtu=FAKE_MTU))
 
     def test_post_network_plug_with_host_routes(self):
         SUBNET_ID = 'SUBNET_ID'
@@ -202,7 +221,8 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                                    subnet=subnet)
         ]
         port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
-                                   fixed_ips=fixed_ips)
+                                   fixed_ips=fixed_ips,
+                                   network=self.network)
         self.driver.post_network_plug(self.amp, port)
         expected_fixed_ips = [
             {'ip_address': FIXED_IP1, 'subnet_cidr': SUBNET_CIDR,
@@ -214,7 +234,8 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         ]
         self.driver.client.plug_network.assert_called_once_with(
             self.amp, dict(mac_address=FAKE_MAC_ADDRESS,
-                           fixed_ips=expected_fixed_ips))
+                           fixed_ips=expected_fixed_ips,
+                           mtu=FAKE_MTU))
 
     def test_get_vrrp_interface(self):
         self.driver.get_vrrp_interface(self.amp)
@@ -238,9 +259,20 @@ class TestAmphoraAPIClientTest(base.TestCase):
                             'gateway': FAKE_GATEWAY,
                             'mac_address': FAKE_MAC_ADDRESS,
                             'vrrp_ip': self.amp.vrrp_ip}
+        patcher = mock.patch('time.sleep').start()
+        self.addCleanup(patcher.stop)
 
+    def test_base_url(self):
+        url = self.driver._base_url(FAKE_IP)
+        self.assertEqual('https://192.0.2.10:9443/0.5/', url)
+        url = self.driver._base_url(FAKE_IPV6)
+        self.assertEqual('https://[2001:db8::cafe]:9443/0.5/', url)
+        url = self.driver._base_url(FAKE_IPV6_LLA)
+        self.assertEqual('https://[fe80::00ff:fe00:cafe%o-hm0]:9443/0.5/', url)
+
+    @mock.patch('requests.Session.get', side_effect=requests.ConnectionError)
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.time.sleep')
-    def test_request(self, mock_sleep):
+    def test_request(self, mock_sleep, mock_get):
         self.assertRaises(driver_except.TimeOutException,
                           self.driver.request,
                           'get', self.amp, 'unavailableURL')
@@ -263,7 +295,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_get_info_missing(self, m):
         m.get("{base}/info".format(base=self.base_url),
-              status_code=404)
+              status_code=404,
+              headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_info, self.amp)
 
     @requests_mock.mock()
@@ -300,7 +333,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_get_details_missing(self, m):
         m.get("{base}/details".format(base=self.base_url),
-              status_code=404)
+              status_code=404,
+              headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_details, self.amp)
 
     @requests_mock.mock()
@@ -336,7 +370,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_get_all_listeners_missing(self, m):
         m.get("{base}/listeners".format(base=self.base_url),
-              status_code=404)
+              status_code=404,
+              headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_all_listeners,
                           self.amp)
 
@@ -377,7 +412,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_listener_status_missing(self, m):
         m.get("{base}/listeners/{listener_id}".format(
             base=self.base_url, listener_id=FAKE_UUID_1),
-            status_code=404)
+            status_code=404,
+            headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound,
                           self.driver.get_listener_status, self.amp,
                           FAKE_UUID_1)
@@ -411,7 +447,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_start_listener_missing(self, m):
         m.put("{base}/listeners/{listener_id}/start".format(
             base=self.base_url, listener_id=FAKE_UUID_1),
-            status_code=404)
+            status_code=404,
+            headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
@@ -450,7 +487,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_stop_listener_missing(self, m):
         m.put("{base}/listeners/{listener_id}/stop".format(
             base=self.base_url, listener_id=FAKE_UUID_1),
-            status_code=404)
+            status_code=404,
+            headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.stop_listener,
                           self.amp, FAKE_UUID_1)
 
@@ -489,9 +527,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_delete_listener_missing(self, m):
         m.delete("{base}/listeners/{listener_id}".format(
             base=self.base_url, listener_id=FAKE_UUID_1),
-            status_code=404)
-        self.assertRaises(exc.NotFound, self.driver.delete_listener,
-                          self.amp, FAKE_UUID_1)
+            status_code=404,
+            headers={'content-type': 'application/json'})
+        self.driver.delete_listener(self.amp, FAKE_UUID_1)
+        self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_delete_listener_unauthorized(self, m):
@@ -612,7 +651,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_get_cert_5sum_missing(self, m):
         m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
             base=self.base_url, listener_id=FAKE_UUID_1,
-            filename=FAKE_PEM_FILENAME), status_code=404)
+            filename=FAKE_PEM_FILENAME), status_code=404,
+            headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_cert_md5sum,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
 
@@ -655,9 +695,11 @@ class TestAmphoraAPIClientTest(base.TestCase):
         m.delete(
             "{base}/listeners/{listener_id}/certificates/{filename}".format(
                 base=self.base_url, listener_id=FAKE_UUID_1,
-                filename=FAKE_PEM_FILENAME), status_code=404)
-        self.assertRaises(exc.NotFound, self.driver.delete_cert_pem, self.amp,
-                          FAKE_UUID_1, FAKE_PEM_FILENAME)
+                filename=FAKE_PEM_FILENAME), status_code=404,
+            headers={'content-type': 'application/json'})
+        self.driver.delete_cert_pem(self.amp, FAKE_UUID_1,
+                                    FAKE_PEM_FILENAME)
+        self.assertTrue(m.called)
 
     @requests_mock.mock()
     def test_delete_cert_pem_unauthorized(self, m):
@@ -755,6 +797,17 @@ class TestAmphoraAPIClientTest(base.TestCase):
         self.driver.plug_vip(self.amp, FAKE_IP, self.subnet_info)
         self.assertTrue(m.called)
 
+    @requests_mock.mock()
+    def test_plug_vip_api_not_ready(self, m):
+        m.post("{base}/plug/vip/{vip}".format(
+            base=self.base_url, vip=FAKE_IP),
+            status_code=404, headers={'content-type': 'text/html'}
+        )
+        self.assertRaises(driver_except.TimeOutException,
+                          self.driver.plug_vip,
+                          self.amp, FAKE_IP, self.subnet_info)
+        self.assertTrue(m.called)
+
     @requests_mock.mock()
     def test_plug_network(self, m):
         m.post("{base}/plug/network".format(
