@@ -13,6 +13,7 @@
 # under the License.
 #
 
+import mock
 from taskflow.patterns import linear_flow as flow
 
 from octavia.common import constants
@@ -20,6 +21,9 @@ from octavia.controller.worker.flows import member_flows
 import octavia.tests.unit.base as base
 
 
+# NOTE: We patch the get_network_driver for all the calls so we don't
+# inadvertently make real calls.
+@mock.patch('octavia.common.utils.get_network_driver')
 class TestMemberFlows(base.TestCase):
 
     def setUp(self):
@@ -27,7 +31,7 @@ class TestMemberFlows(base.TestCase):
 
         super(TestMemberFlows, self).setUp()
 
-    def test_get_create_member_flow(self):
+    def test_get_create_member_flow(self, mock_get_net_driver):
 
         member_flow = self.MemberFlow.get_create_member_flow()
 
@@ -35,32 +39,36 @@ class TestMemberFlows(base.TestCase):
 
         self.assertIn(constants.LISTENERS, member_flow.requires)
         self.assertIn(constants.LOADBALANCER, member_flow.requires)
+        self.assertIn(constants.POOL, member_flow.requires)
 
-        self.assertEqual(2, len(member_flow.requires))
+        self.assertEqual(4, len(member_flow.requires))
         self.assertEqual(2, len(member_flow.provides))
 
-    def test_get_delete_member_flow(self):
+    def test_get_delete_member_flow(self, mock_get_net_driver):
 
         member_flow = self.MemberFlow.get_delete_member_flow()
 
         self.assertIsInstance(member_flow, flow.Flow)
 
+        self.assertIn(constants.MEMBER, member_flow.requires)
         self.assertIn(constants.LISTENERS, member_flow.requires)
         self.assertIn(constants.LOADBALANCER, member_flow.requires)
-        self.assertIn(constants.MEMBER, member_flow.requires)
+        self.assertIn(constants.POOL, member_flow.requires)
 
-        self.assertEqual(3, len(member_flow.requires))
+        self.assertEqual(4, len(member_flow.requires))
         self.assertEqual(0, len(member_flow.provides))
 
-    def test_get_update_member_flow(self):
+    def test_get_update_member_flow(self, mock_get_net_driver):
 
         member_flow = self.MemberFlow.get_update_member_flow()
 
         self.assertIsInstance(member_flow, flow.Flow)
 
+        self.assertIn(constants.MEMBER, member_flow.requires)
         self.assertIn(constants.LISTENERS, member_flow.requires)
         self.assertIn(constants.LOADBALANCER, member_flow.requires)
+        self.assertIn(constants.POOL, member_flow.requires)
         self.assertIn(constants.UPDATE_DICT, member_flow.requires)
 
-        self.assertEqual(4, len(member_flow.requires))
+        self.assertEqual(5, len(member_flow.requires))
         self.assertEqual(0, len(member_flow.provides))
